@@ -361,6 +361,10 @@ class py2app(Command):
             if os.path.exists(iconfile):
                 self.iconfile = iconfile
 
+
+        if self.iconfile is not None:
+            self.resources.append(self.iconfile)
+
         self.runtime_preferences = list(self.get_runtime_preferences())
 
 
@@ -815,11 +819,10 @@ class py2app(Command):
                     if os.path.exists(fn):
                         prefix = open(fn, 'rU').read().strip()
 
-                    rest_path = sys.executable[len(sys.prefix)+1:]
+                    rest_path = os.path.normpath(sys.executable)[len(os.path.normpath(sys.prefix))+1:]
                     if rest_path.startswith('.'):
                         rest_path = rest_path[1:]
 
-                    print "XXXX", os.path.join(prefix, rest_path)
                     self.copy_file(os.path.join(prefix, rest_path), execdst)
 
                 else:
@@ -1375,6 +1378,16 @@ class py2app(Command):
                 fp.write('aliases = {}\n')
                 fp.close()
 
+        for src, dest in self.iter_data_files():
+            dest = os.path.join(resdir, dest)
+            if src == dest:
+                continue
+            makedirs(os.path.dirname(dest))
+            if os.path.isdir(src):
+                self.copy_tree(src, dest, preserve_symlinks=False)
+            else:
+                self.copy_file(src, dest)
+
 
         target.appdir = appdir
         return appdir
